@@ -18,7 +18,7 @@ def test_cheat_hash():
         [1, 2, 3.4],
         (1, 2, 3.4),
         {1: 2, 3: 4.5},
-        set((1, 2, 3.4)),
+        {1, 2, 3.4},
         [1, [1, 2], 3],
         [1, {frozenset((1, 2)): 'meow'}, 3],
         sum,
